@@ -1,12 +1,12 @@
 import logging
-import pooraka.utils as utils
+from pooraka.utils import AverageMeter, accuracy
 import torch
 import time
 
 def infer_cifar(args, valid_queue, model, criterion, logging_mode=False):
-    objs = utils.AverageMeter()
-    top1 = utils.AverageMeter()
-    top5 = utils.AverageMeter()
+    objs = AverageMeter()
+    top1 = AverageMeter()
+    top5 = AverageMeter()
     model.eval()
     with torch.no_grad():
         for step, (input, target) in enumerate(valid_queue):
@@ -16,7 +16,7 @@ def infer_cifar(args, valid_queue, model, criterion, logging_mode=False):
             logits = model(input)
             loss = criterion(logits, target)             
 
-            prec1, prec5 = utils.accuracy(logits, target, topk=(1, 5))
+            prec1, prec5 = accuracy(logits, target, topk=(1, 5))
             n = input.size(0)
             objs.update(loss.item(), n)
             top1.update(prec1.item(), n)
@@ -28,9 +28,9 @@ def infer_cifar(args, valid_queue, model, criterion, logging_mode=False):
     return top1.avg, objs.avg
 
 def infer_imagenet(args, valid_queue, model, criterion, logging_mode=False):
-    objs = utils.AverageMeter()
-    top1 = utils.AverageMeter()
-    top5 = utils.AverageMeter()
+    objs = AverageMeter()
+    top1 = AverageMeter()
+    top5 = AverageMeter()
     model.eval()
 
     for step, (input, target) in enumerate(valid_queue):
@@ -40,7 +40,7 @@ def infer_imagenet(args, valid_queue, model, criterion, logging_mode=False):
             logits = model(input)
             loss = criterion(logits, target)
 
-        prec1, prec5 = utils.accuracy(logits, target, topk=(1, 5))
+        prec1, prec5 = accuracy(logits, target, topk=(1, 5))
         n = input.size(0)
         objs.update(loss.data.item(), n)
         top1.update(prec1.data.item(), n)
